California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROPOSITION 047 - CRIMINAL SENTENCES. MISDEMEANOR PENALTIES. INITIATIVE STATUTE. View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1355516 | WOMEN'S FOUNDATION OF CALIFORNIA - YES ON 47 (NONPROFIT 501(C)(3)), THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1368083 | CALIFORNIANS AGAINST PROP. 47, SPONSORED BY CALIFORNIA PUBLIC SAFETY INSTITUTE AND PEACE OFFICERS RESEARCH ASSOCIATION OF CALIFORNIA PIC | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1362944 | YES ON PROP. 47, CALIFORNIANS FOR SAFE NEIGHBORHOODS AND SCHOOLS, SPONSORED BY VOTE SAFE, A PROJECT OF THE ADVOCACY FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1369552 | YES ON 47 SPONSORED BY PICO CALIFORNIA PICO ACTION FUND | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1373275 | SIXTEEN THIRTY FUND ( NONPROFIT 501 (C) (4) ) YES ON 47, THE | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372105 | CALIFORNIA CALLS ACTION FUND - YES ON 47 - A COALITION OF SOCIAL JUSTICE ORGANIZATIONS | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1372760 | PICO CALIFORNIA - YES ON 47 (NON PROFIT 501 (C) (3)) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1365560 | OPEN SOCIETY POLICY CENTER (NON-PROFIT 501 (C) (4) - YES ON 47) | SUPPORT
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1373039 | AMERICAN CIVIL LIBERTIES UNION, INC. (NONPROFIT 501(C)(4)) | SUPPORT